## 0.13.2.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 0.13.2.8 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.13.2.7 (2023-04-17)

`keyboard` : Update `stubtest_allowlist` and add comments for missing defaults (#9965)

## 0.13.2.6 (2023-03-27)

Add defaults for third-party stubs I-L (#9955)

## 0.13.2.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.13.2.4 (2023-02-07)

Enable flake8-pyi's Y037 (#9686)

## 0.13.2.3 (2023-01-13)

Allowlist-only fixes for stubtest on Windows (#9522)

## 0.13.2.2 (2022-11-14)

Comments explaining why `keyboard` and `tzlocal` are not run on multiple platforms (#9188)

## 0.13.2.1 (2022-11-03)

Update pyright to 1.1.278 (#9077)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 0.13.2 (2022-09-27)

Bump mypy to 0.981 (#8796)

## 0.13.1 (2022-09-22)

Add reportMissingParameterType to `pyrightconfig.stricter.json` (#8770)

## 0.13.0 (2022-09-06)

Added stubs for keyboard (#8666)

